@@ -34,6 +34,7 @@ def download(ctx, urls, output_dir, input_file, quiet):
         while True:
             try:
                 url = click.prompt("", prompt_suffix="", type=str)
+                url = url.strip()
                 if url[0] == "q" or len(url) == 0:
                     break
             except click.Abort:
@@ -42,5 +43,6 @@ def download(ctx, urls, output_dir, input_file, quiet):
             download_urls.append(url)
     try:
         download_files(download_urls, output_dir)
-    except:
-        return
+    except Exception as e:
+        click.secho(str(e), fg="red")
+        sys.exit(1)
